@@ -26,7 +26,7 @@ use Encode 'encode';
 
 use Carp 'confess';
 
-our $VERSION = '0.0259';
+our $VERSION = '0.0260';
 
 our $COMPILER;
 our @PACKAGE_INFOS;
@@ -64,14 +64,13 @@ sub _get_dll_file {
   my $package_name = shift;
   
   # DLL file name
-  my $dlext = $Config{dlext};
   my $dll_base_name = $package_name;
   $dll_base_name =~ s/^.*:://;
   my $dll_file_tail = 'auto/' . $package_name . '/' . $dll_base_name;
   $dll_file_tail =~ s/::/\//g;
   my $dll_file;
   for my $dl_shared_object (@DynaLoader::dl_shared_objects) {
-    my $dl_shared_object_no_ext = $dl_shared_object . '.ppp';
+    my $dl_shared_object_no_ext = $dl_shared_object;
     # remove .so, xs.dll .dll, etc
     while ($dl_shared_object_no_ext =~ s/\.[^\/\.]+$//) {
       1;
@@ -111,8 +110,6 @@ sub search_native_address {
 sub get_sub_native_address {
   my $sub_abs_name = shift;
   
-  my $native_address;
-  
   my $package_name;
   my $sub_name;
   if ($sub_abs_name =~ /^(?:(.+)::)(.+)$/) {
@@ -120,29 +117,14 @@ sub get_sub_native_address {
     $sub_name = $2;
   }
   
-  my $dll_file;
   my $dll_package_name = $package_name;
-  while (1) {
-    $dll_file = _get_dll_file($dll_package_name);
-    $native_address = search_native_address($dll_file, $sub_abs_name);
-    
-    if ($native_address) {
-      last;
-    }
-    else {
-      if ($dll_package_name =~ /::/) {
-        $dll_package_name =~ s/::[^:]+$//;
-      }
-      else {
-        last;
-      }
-    }
-  }
-  
+  my $dll_file = _get_dll_file($dll_package_name);
+  my $native_address = search_native_address($dll_file, $sub_abs_name);
+
   # Search inline dlls
-  my $package_name_tmp = $package_name;
-  $package_name_tmp =~ s/:/_/g;
   unless ($native_address) {
+    my $package_name_tmp = $package_name;
+    $package_name_tmp =~ s/:/_/g;
     for my $dll_file (@INLINE_DLL_FILES) {
       if ($dll_file =~ /\Q$package_name_tmp/) {
         $native_address = search_native_address($dll_file, $sub_abs_name);
@@ -211,11 +193,10 @@ sub compile_inline_native_subs {
       }
     }
     
-    my $spvm_tmp_file = $package_name;
-    $spvm_tmp_file =~ s/:/_/g;
-    $spvm_tmp_file = "SPVM__${spvm_tmp_file}.c";
+    my $package_name_under_score = $package_name;
+    $package_name_under_score =~ s/:/_/g;
     
-    my $native_src_file = "$temp_dir/$spvm_tmp_file";
+    my $native_src_file = "$temp_dir/SPVM__${package_name_under_score}.c";
     
     open my $native_src_fh, '>', $native_src_file
       or die "Can't open $native_src_file:$!";
@@ -285,7 +266,26 @@ sub compile_inline_native_subs {
       source => $native_src_file,
       include_dirs => [$api_header_include_dir]
     );
-    my $lib_file = $cbuilder->link(objects => $obj_file);
+    
+    # This is required for Windows
+    my $native_sub_names = get_native_sub_names_from_package($package_name);
+    my $dl_func_list = [];
+    for my $native_sub_name (@$native_sub_names) {
+      my $dl_func = "SPVM__$native_sub_name";
+      $dl_func =~ s/:/_/g;
+      push @$dl_func_list, $dl_func;
+    }
+    my $boot_name = "boot_SPVM__${package_name_under_score}";
+    push @$dl_func_list, $boot_name;
+    
+    my $lib_file_name = "$temp_dir/SPVM__${package_name_under_score}.$Config{dlext}";
+    
+    my $lib_file = $cbuilder->link(
+      objects => $obj_file,
+      module_name => "SPVM::$package_name",
+      dl_func_list => $dl_func_list,
+      lib_file => $lib_file_name
+    );
     
     push @INLINE_DLL_FILES, $lib_file;
   }
@@ -295,6 +295,12 @@ sub compile_inline_native_subs {
 CHECK {
   require XSLoader;
   XSLoader::load('SPVM', $VERSION);
+
+  # I want to load dll file from Package name
+  # but XSLoader::load call boot_ function and error occur
+  # so I surround eval. This is very bad hack
+  XSLoader::load('SPVM::std', $VERSION);
+  XSLoader::load('SPVM::Math', $VERSION);
   
   # Compile SPVM source code
   compile();
